@@ -1,7 +1,7 @@
 
 install.blk<-function(x){
 
-if(x=="osx" | x=="linux"){install.packages("UScensus2000blk", repos="http://disasternets.calit2.uci.edu/census2000/R/",type="source")
+if(x=="osx" | x=="linux"){install.packages("UScensus2000blk", repos="http://lakshmi.calit2.uci.edu/census2000/R/",type="source")
 	return()
 	}
 
@@ -9,7 +9,7 @@ if(x=="windows"){
 	rVer<-as.numeric(R.Version()$minor)
 	
 	if(rVer>=11){
-		install.packages("UScensus2000blk", repos="http://disasternets.calit2.uci.edu/census2000/R/",type="source")
+		install.packages("UScensus2000blk", repos="http://lakshmi.calit2.uci.edu/census2000/R/",type="source")
 		return()
 		}else{stop("Not Available Yet")}
 }
